==> tinyos_mitmot_patch-0.2.zip: tos/platform/mitmot/hardware.h <==
// $Id: hardware.h,v 1.1 2004/08/10 03:30:57 husq Exp $

/*									tab:4
 * "Copyright (c) 2000-2003 The Regents of the University  of California.  
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without written agreement is
 * hereby granted, provided that the above copyright notice, the following
 * two paragraphs and the author appear in all copies of this software.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY FOR
 * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
 * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF
 * CALIFORNIA HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
 * ON AN "AS IS" BASIS, AND THE UNIVERSITY OF CALIFORNIA HAS NO OBLIGATION TO
 * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS."
 *
 * Copyright (c) 2002-2003 Intel Corporation
 * All rights reserved.
 *
 * This file is distributed under the terms in the attached INTEL-LICENSE     
 * file. If you do not find these files, copies can be found by writing to
 * Intel Research Berkeley, 2150 Shattuck Avenue, Suite 1300, Berkeley, CA, 
 * 94704.  Attention:  Intel License Inquiry.
 */
/*									tab:4
 *  IMPORTANT: READ BEFORE DOWNLOADING, COPYING, INSTALLING OR USING.  By
 *  downloading, copying, installing or using the software you agree to
 *  this license.  If you do not agree to this license, do not download,
 *  install, copy or use the software.
 *
 *  Intel Open Source License 
 *
 *  Copyright (c) 2002 Intel Corporation 
 *  All rights reserved. 
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 * 
 *	Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *	Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *      Neither the name of the Intel Corporation nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 *  PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE INTEL OR ITS
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * 
 */
/*
 *
 * $Id: hardware.h,v 1.1 2004/08/10 03:30:57 husq Exp $
 *
 */

#ifndef TOSH_HARDWARE_H
#define TOSH_HARDWARE_H

#ifndef TOSH_HARDWARE_MITMOT
#define TOSH_HARDWARE_MITMOT
#endif // tosh hardware

#define TOSH_NEW_AVRLIBC // mica128 requires avrlibc v. 20021209 or greater
#include <avrhardware.h>
//#include <CC2420Const.h>

// avrlibc may define ADC as a 16-bit register read.  This collides with the nesc
// ADC interface name
uint16_t inline getADC() {
  return inw(ADC);
}
#undef ADC

#define TOSH_CYCLE_TIME_NS 136

// each nop is 1 clock cycle
// 1 clock cycle on mitmot == 125 ns
void inline TOSH_wait_250ns() {
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
}

void inline TOSH_uwait(int u_sec) {
    while (u_sec > 0) {
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      u_sec--;
    }
}

//PIN assignments
TOSH_ASSIGN_PIN(GPIO_0, A, 0);
TOSH_ASSIGN_PIN(GPIO_1, A, 1);
TOSH_ASSIGN_PIN(GPIO_2, A, 2);
TOSH_ASSIGN_PIN(GPIO_3, A, 3);
TOSH_ASSIGN_PIN(GPIO_4, A, 4);
TOSH_ASSIGN_PIN(GPIO_5, A, 5);
TOSH_ASSIGN_PIN(GPIO_6, A, 6);
TOSH_ASSIGN_PIN(GPIO_7, A, 7);
TOSH_ASSIGN_PIN(GPIO_8, C, 0);
TOSH_ASSIGN_PIN(GPIO_9, C, 1);
TOSH_ASSIGN_PIN(GPIO_10, C, 2);
TOSH_ASSIGN_PIN(GPIO_11, C, 3);
TOSH_ASSIGN_PIN(GPIO_12, C, 4);
TOSH_ASSIGN_PIN(GPIO_13, C, 5);
TOSH_ASSIGN_PIN(GPIO_14, C, 6);
TOSH_ASSIGN_PIN(GPIO_15, C, 7);

TOSH_ASSIGN_PIN(SYS_LED, D, 7);

/*
// LED assignments
TOSH_ASSIGN_PIN(RED_LED, D, 7);
TOSH_ASSIGN_PIN(GREEN_LED, A, 1);
TOSH_ASSIGN_PIN(YELLOW_LED, A, 2);

TOSH_ASSIGN_PIN(SERIAL_ID, A, 4);
TOSH_ASSIGN_PIN(BAT_MON, A, 5);
TOSH_ASSIGN_PIN(THERM_PWR, A, 7);
*/


// interrupt assignments
TOSH_ASSIGN_PIN(INT0, E, 5);
TOSH_ASSIGN_PIN(INT1, E, 6);

// SPI bus assignments 
TOSH_ASSIGN_PIN(MOSI,  B, 2);
TOSH_ASSIGN_PIN(MISO,  B, 3);
TOSH_ASSIGN_PIN(SPI_SSEL, B, 0);
TOSH_ASSIGN_PIN(SPI_SCK,  B, 1);


// i2c bus assignments
TOSH_ASSIGN_PIN(I2C_BUS1_SCL, D, 0);
TOSH_ASSIGN_PIN(I2C_BUS1_SDA, D, 1);

// uart assignments
TOSH_ASSIGN_PIN(UART_RXD0, E, 0);
TOSH_ASSIGN_PIN(UART_TXD0, E, 1);
TOSH_ASSIGN_PIN(UART_XCK0, E, 2)

TOSH_ASSIGN_PIN(UART_RXD1, D, 2);
TOSH_ASSIGN_PIN(UART_TXD1, D, 3);
TOSH_ASSIGN_PIN(UART_XCK1, D, 5);

void TOSH_SET_PIN_DIRECTIONS(void)
{
	//TODO : nem hasnlt lbak belltsa!
	DDRA  = 0;
	DDRB  = 0;
	DDRC  = 0;
	DDRD  = 0;
	DDRE  = 0; // INPUT
	PORTA = 0xff;
	PORTB = 0xff;
	PORTC = 0xff;
	PORTD = 0xff;
	PORTE = 0xff;
	TOSH_MAKE_SYS_LED_OUTPUT();
	TOSH_CLR_SYS_LED_PIN();

}


enum {
  TOSH_ADC_PORTMAPSIZE = 12
};

#endif //TOSH_HARDWARE_H

==> tinyos_mitmot_patch-0.3.zip: tos/platform/mitmot/hardware.h <==

/*									tab:4
 * "Copyright (c) 2000-2003 The Regents of the University  of California.  
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without written agreement is
 * hereby granted, provided that the above copyright notice, the following
 * two paragraphs and the author appear in all copies of this software.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY FOR
 * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
 * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF
 * CALIFORNIA HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
 * ON AN "AS IS" BASIS, AND THE UNIVERSITY OF CALIFORNIA HAS NO OBLIGATION TO
 * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS."
 *
 * Copyright (c) 2002-2003 Intel Corporation
 * All rights reserved.
 *
 * This file is distributed under the terms in the attached INTEL-LICENSE     
 * file. If you do not find these files, copies can be found by writing to
 * Intel Research Berkeley, 2150 Shattuck Avenue, Suite 1300, Berkeley, CA, 
 * 94704.  Attention:  Intel License Inquiry.
 */
/*									tab:4
 *  IMPORTANT: READ BEFORE DOWNLOADING, COPYING, INSTALLING OR USING.  By
 *  downloading, copying, installing or using the software you agree to
 *  this license.  If you do not agree to this license, do not download,
 *  install, copy or use the software.
 *
 *  Intel Open Source License 
 *
 *  Copyright (c) 2002 Intel Corporation 
 *  All rights reserved. 
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 * 
 *	Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *	Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *      Neither the name of the Intel Corporation nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 *  PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE INTEL OR ITS
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * 
 */
/*
 *
 * $Id: hardware.h,v 1.1 2004/08/10 03:30:57 husq Exp $
 *
 */

#ifndef TOSH_HARDWARE_H
#define TOSH_HARDWARE_H

#ifndef TOSH_HARDWARE_MITMOT
#define TOSH_HARDWARE_MITMOT
#endif // tosh hardware

#define TOSH_NEW_AVRLIBC // mica128 requires avrlibc v. 20021209 or greater
#include <avrhardware.h>
//#include <CC2420Const.h>

// avrlibc may define ADC as a 16-bit register read.  This collides with the nesc
// ADC interface name
uint16_t inline getADC() {
  return inw(ADC);
}
#undef ADC

#define TOSH_CYCLE_TIME_NS 136

// each nop is 1 clock cycle
// 1 clock cycle on mitmot == 125 ns
void inline TOSH_wait_250ns() {
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
}

void inline TOSH_uwait(int u_sec) {
    while (u_sec > 0) {
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      asm volatile  ("nop" ::);
      u_sec--;
    }
}

//PIN assignments
TOSH_ASSIGN_PIN(GPIO_0, A, 0);
TOSH_ASSIGN_PIN(GPIO_1, A, 1);
TOSH_ASSIGN_PIN(GPIO_2, A, 2);
TOSH_ASSIGN_PIN(GPIO_3, A, 3);
TOSH_ASSIGN_PIN(GPIO_4, A, 4);
TOSH_ASSIGN_PIN(GPIO_5, A, 5);
TOSH_ASSIGN_PIN(GPIO_6, A, 6);
TOSH_ASSIGN_PIN(GPIO_7, A, 7);
TOSH_ASSIGN_PIN(GPIO_8, C, 0);
TOSH_ASSIGN_PIN(GPIO_9, C, 1);
TOSH_ASSIGN_PIN(GPIO_10, C, 2);
TOSH_ASSIGN_PIN(GPIO_11, C, 3);
TOSH_ASSIGN_PIN(GPIO_12, C, 4);
TOSH_ASSIGN_PIN(GPIO_13, C, 5);
TOSH_ASSIGN_PIN(GPIO_14, C, 6);
TOSH_ASSIGN_PIN(GPIO_15, C, 7);

TOSH_ASSIGN_PIN(SYS_LED, D, 7);

// interrupt assignments
TOSH_ASSIGN_PIN(INT0, E, 5);  //AVR INT5!
TOSH_ASSIGN_PIN(INT1, E, 6);  //AVR INT6!
TOSH_ALIAS_PIN(EXT_INT0, INT0);
TOSH_ALIAS_PIN(EXT_INT1, INT1);


// SPI bus assignments 
TOSH_ASSIGN_PIN(MOSI,  B, 2);
TOSH_ASSIGN_PIN(MISO,  B, 3);
TOSH_ASSIGN_PIN(SPI_SSEL, B, 0);
TOSH_ASSIGN_PIN(SPI_SCK,  B, 1);


// i2c bus assignments
TOSH_ASSIGN_PIN(I2C_BUS1_SCL, D, 0);
TOSH_ASSIGN_PIN(I2C_BUS1_SDA, D, 1);

// uart assignments
TOSH_ASSIGN_PIN(UART_RXD0, E, 0);
TOSH_ASSIGN_PIN(UART_TXD0, E, 1);
TOSH_ASSIGN_PIN(UART_XCK0, E, 2)

TOSH_ASSIGN_PIN(UART_RXD1, D, 2);
TOSH_ASSIGN_PIN(UART_TXD1, D, 3);
TOSH_ASSIGN_PIN(UART_XCK1, D, 5);

// PWM
TOSH_ASSIGN_PIN(PWM0, B, 5); // Timer1 output compare/PWM
TOSH_ASSIGN_PIN(PWM1, B, 6); // Timer1 output compare/PWM

// Timer/capture
TOSH_ASSIGN_PIN(TCAP0, D, 4);  // ICP1
TOSH_ASSIGN_PIN(TCAP1, E, 7);  // INT7 / ICP3

// Analog comparator
// Connected to ADC0 and ADC1!!!
TOSH_ASSIGN_PIN(AIN0, E, 2);
TOSH_ASSIGN_PIN(AIN1, E, 3);  // OC3A (Timer3 PWM)

// ADC
TOSH_ASSIGN_PIN(ADC0, F, 0);
TOSH_ASSIGN_PIN(ADC1, F, 1);
TOSH_ASSIGN_PIN(ADC2, F, 2);
TOSH_ASSIGN_PIN(ADC3, F, 3);

void TOSH_SET_PIN_DIRECTIONS(void) {
	//TODO : nem hasnlt lbak belltsa!
	DDRA  = 0;
	DDRB  = 0;
	DDRC  = 0;
	DDRD  = 0;
	DDRE  = 0; // INPUT
	PORTA = 0xff;
	PORTB = 0xff;
	PORTC = 0xff;
	PORTD = 0xff;
	PORTE = 0xff;
	TOSH_MAKE_SYS_LED_OUTPUT();
	TOSH_CLR_SYS_LED_PIN();
	TOSH_MAKE_I2C_BUS1_SCL_INPUT();
	TOSH_MAKE_I2C_BUS1_SDA_INPUT();

	TOSH_SET_I2C_BUS1_SCL_PIN();
	TOSH_SET_I2C_BUS1_SDA_PIN();

	TOSH_MAKE_ADC0_INPUT();
	TOSH_MAKE_ADC1_INPUT();
	TOSH_MAKE_ADC2_INPUT();
	TOSH_MAKE_ADC3_INPUT();

	TOSH_MAKE_AIN0_INPUT();
	TOSH_MAKE_AIN1_INPUT();

}


enum {
  TOSH_ADC_PORTMAPSIZE = 12
};

#endif //TOSH_HARDWARE_H
